==========
User Guide
==========

The Device plugin handles the connections to the Peek server, manages it's
online state, and manages software updates.

Connecting To Peek Server
-------------------------

Web based Peek apps know which server to connect to, and you will not see the
connection screen on those apps.

For Peek Field, you will need to set the address of the Peek Server.

Device Name
-----------

Before your Peek app can connect to a peek server, you must enter a description
of where the app is running, for example your laptops asset id or your name,
for example.

*  NC2343 Chrome
*  Jacks's iPhone Native

Your Peek app must be approved by a Peek administrator before it is allowed to
connect to the server. Administrators can set the server to auto approve, in
which case you will not be directed to approval screen at all.

